<?php

namespace Teknisa\FIN\Modules\MovimentacaoBancaria\Factories;

use Doctrine\ORM\EntityManager;
use Teknisa\Model\Geral\Entities\Paramgeral;
use Teknisa\Model\Financeiro\Entities\Orcafina;
use Teknisa\Libs\Util\DateUtil;

class Bco00500RecalculoOrcamentoFluxoCaixaFactory{

    public function __construct($entityManager) {
        $this->entityManager = $entityManager;
    }

    public function getDatasPeriodos($dataInicial, $dataFinal, $nrorg) {
        $params = array(
            'DTINICIAL' => $dataInicial,
            'DTFINAL'   => $dataFinal,
            'NRORG'     => $nrorg
          );
        $sql = "SELECT DISTINCT TO_CHAR(DTMES, 'DD/MM/YYYY') DTMES
                  FROM DATA
                 WHERE (DTDATA between :DTINICIAL and :DTFINAL)
                   AND (NRORG = :NRORG)
                 ORDER BY DTMES";
        $std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }

    public function getValorTotalContas($params) {
        $sql = "SELECT SUM(VRATUAPAG) VRATUAPAG
                  FROM CONTAPAGAR CT,NOTAFISCAL NF
                 WHERE (CT.CDFILIAL    = NF.CDFILIAL)
                   AND (CT.NRLANCTONF  = NF.NRLANCTONF)
                   AND (CT.NRORG       = NF.NRORG)
                   AND (NF.IDSTATUS    IN ('A','V'))
                   AND (CT.CDEMPRESA   = :CDEMPRESA)
                   AND (CDFIMOVFLPAG   = :CDFILIAL)
                   AND (CT.CDCLASSFINA = :CDCLASSFINA)
                   AND (CT.NRORG       = :NRORG)
                   AND (CT.DTMOVFLUXO  BETWEEN :DTMOVFLUXO_INI  AND :DTMOVFLUXO_FIN)";
        $std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute($params);
        return $std->fetch();
    }

    public function getTotalAjusteBoleto($params) {
        $sql = "SELECT VRAJUSTE,
                       TIPOAJUS
                  FROM
                     (SELECT SUM(MF.VRFXAJBOLPAG) VRAJUSTE,
                             'DESCONTO'           TIPOAJUS
                        FROM MOVFXAJBOLP MF,
                             TIPOAJPAGAR TP
                       WHERE (MF.CDEMPRESA   = :CDEMPRESA) AND
                             (MF.CDFILIAL    = :CDFILIAL) AND
                             (MF.CDCLASSFINA = :CDCLASSFINA) AND
                             (MF.NRORG       = :NRORG) AND
                             (MF.NRORG       = TP.NRORG) AND
                             (MF.DTMOVFLUXO BETWEEN :DTMOVFLUXO_INI AND :DTMOVFLUXO_FIN) AND
                             (TP.IDAJUCTPAG = 'D') AND
                             (TP.CDAJUCTPAG = MF.CDAJUCTPAG)
                       UNION ALL
                      SELECT SUM(MF.VRFXAJBOLPAG) VRAJUSTE,
                             'ACRESCIMO'        TIPOAJUS
                        FROM MOVFXAJBOLP MF,
                             TIPOAJPAGAR TP
                       WHERE (MF.CDEMPRESA   = :CDEMPRESA) AND
                             (MF.CDFILIAL    = :CDFILIAL) AND
                             (MF.CDCLASSFINA = :CDCLASSFINA) AND
                             (MF.NRORG       = :NRORG) AND
                             (MF.NRORG       = TP.NRORG) AND
                             (MF.DTMOVFLUXO BETWEEN :DTMOVFLUXO_INI AND :DTMOVFLUXO_FIN) AND
                             (TP.IDAJUCTPAG = 'A') AND
                             (TP.CDAJUCTPAG  = MF.CDAJUCTPAG))";
        $std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }

    public function getParamGeral($nrorg){
        $params = array();
        $params['nrorg'] = $nrorg;
        $paramGeral = $this->entityManager->getRepository(Paramgeral::class)->findOneBy($params);
        return $paramGeral;
    }

    public function getOrcafina($cdempresa, $cdfilial, $cdclassfina, $dtorcafina, $nrorg){
        $params = array();
        $params['cdempresa']   = $cdempresa;
        $params['cdfilial']    = $cdfilial;
        $params['cdclassfina'] = $cdclassfina;
        $params['dtorcafina']  = $dtorcafina;
        $params['nrorg']       = $nrorg;
        $orcafina = $this->entityManager->getRepository(Orcafina::class)->findOneBy($params);
        return $orcafina;
    }

    public function insereOrcafina($totalTitulo, $vrextoleorca, $vrorcafina, $cdempresa, $cdfilial, $cdclassfina, $dtorcafina, $nrorg){
        $orcafina = new Orcafina();
        $orcafina->setVrrealorca($totalTitulo);
        $orcafina->setVrorcafina($vrorcafina);
        $orcafina->setVrextoleorca($vrextoleorca);
        $orcafina->setCdempresa($cdempresa);
        $orcafina->setCdfilial($cdfilial);
        $orcafina->setCdclassfina($cdclassfina);
        $orcafina->setDtorcafina($dtorcafina);
        $orcafina->setNrorg($nrorg);
        $orcafina->setDtinclusao(DateUtil::getDataAtual());
        return $orcafina;
    }

    public function getPeriodoOrcaFina($empresa, $filial, $anoini, $anofim) {
        $params = array(
            'EMPRESA' => $empresa,
            'FILIAL'  => $filial,
            'ANOFIM'  => $anofim,
            'ANOINI'  => $anoini
        );
        $sql = "SELECT CDCLASSFINA,
                       CDEMPRESA,
                       DTORCAFINA,
                       VRORCAFINA,
                       VREXTOLEORCA,
                       CDFILIAL
                  FROM ORCAFINA
                 WHERE CDEMPRESA  = :EMPRESA AND
                       CDFILIAL   = :FILIAL  AND
                       DTORCAFINA BETWEEN :ANOINI AND :ANOFIM
                 ORDER BY
                       CDEMPRESA,
                       CDFILIAL,
                       CDCLASSFINA,
                       DTORCAFINA";
        $std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }

    public function getFilial($cdempresa, $nrorg){
        $params = array(
            'DTINICIAL' => $dataInicial,
            'DTFINAL'   => $dataFinal,
            'NRORG'     => $nrorg
        );
        $sql = "SELECT CDEMPRESA,
                       CDFILIAL,
                       NMFILIAL
                  FROM FILIAL
                 WHERE (CDEMPRESA = :P_EMPRESA)  AND
                       (INSTR(:P_FILIAL, CDFILIAL) <> 0 OR :P_TFILIAL = 'T' )
                 ORDER BY CDFILIAL";
        $std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
}
